netapp_ontap.models.ems_filter_rule_message_criteria API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.ems_filter_rule_message_criteria`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class EmsFilterRuleMessageCriteriaSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the EmsFilterRuleMessageCriteria object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `links GET`

    The links field of the ems_filter_rule_message_criteria.

  `name_pattern GET POST PATCH`

    Message name filter on which to match. Supports wildcards. Defaults to * if not specified.

    Example: callhome.*

  `severities GET POST PATCH`

    A comma-separated list of severities or a wildcard.

    Example: error,informational

  `snmp_trap_types GET POST PATCH`

    A comma separated list of snmp_trap_types or a wildcard.

    Example: standard|built_in